# FreeBSD newsyslog configuration for rkhunter logs
# logfilename                         [owner:group]  mode count size when flags [/pid_file] [sig_num]
/var/log/rkhunter/rkhunter.log        root:wheel     644  7     1024 @T00  Z
