# FreeBSD newsyslog configuration for Lynis logs
# logfilename                         [owner:group]  mode count size when flags [/pid_file] [sig_num]
/var/log/lynis/lynis.log              root:wheel     644  12    2048 @T00  Z
/var/log/lynis/lynis-report.dat       root:wheel     644  12    2048 @T00  Z
