# FreeBSD newsyslog configuration for chkrootkit logs
# logfilename                       [owner:group]  mode count size when flags [/pid_file] [sig_num]
/var/log/chkrootkit/chkrootkit.log  root:wheel     644  4     1024 @T00  Z
